@@ -11,7 +11,7 @@
 
 
 static NSInteger const kMaxLaunchTimeInSeconds = 15;
-static NSString * const kVersion = @"1.9.3";
+static NSString * const kVersion = @"1.10.2";
 static NSString * const kJsPrintSource = @"(function() { return document.getElementsByTagName('html')[0].outerHTML })();";
 
 
@@ -700,7 +700,7 @@ static NSString * const kJsPrintSource = @"(function() { return document.getElem
 - (chromeWindow *)findWindowWithTab:(chromeTab *)tab {
     for (chromeWindow *window in self.chrome.windows) {
         for (chromeTab *t in window.tabs) {
-            if (t.id == tab.id) {
+            if ([t.id isEqualToString:tab.id]) {
                 return window;
             }
         }
@@ -714,7 +714,7 @@ static NSString * const kJsPrintSource = @"(function() { return document.getElem
     int i = 1;
 
     for (chromeTab *t in window.tabs) {
-        if (t.id == tab.id) {
+        if ([t.id isEqualToString:tab.id]) {
             return i;
         }
         i++;
